<?php

namespace WHP;

require_once('/docker/whp/web/libs/mysqlmgmt.php');
require_once('BackupEngine.php');

use PDO;
use Exception;
use WHPBackup\BackupEngine;

class WordPressManager {
    private $db;
    private $backupEngine;
    
    public function __construct() {
        $mysql = new \mysqlmgmt();
        $this->db = $mysql->getMySQLConnection();
        $this->db->exec("USE whp");
        $this->backupEngine = new BackupEngine();
    }
    
    /**
     * Execute WP-CLI command in a container
     */
    private function execWpCli($container, $user, $command, $workDir = null) {
        if ($workDir === null) {
            $workDir = "/home/{$user}/public_html";
        }
        
        // Build the docker exec command
        $dockerCmd = sprintf(
            "docker exec --user %s -w %s %s %s",
            escapeshellarg($user),
            escapeshellarg($workDir),
            escapeshellarg($container),
            $command
        );
        
        // Log the command for debugging
        error_log("Executing WP-CLI: $dockerCmd");
        
        $output = [];
        $returnCode = 0;
        exec($dockerCmd . " 2>&1", $output, $returnCode);
        
        $result = [
            'success' => $returnCode === 0,
            'output' => implode("\n", $output),
            'return_code' => $returnCode
        ];
        
        // Log errors
        if (!$result['success']) {
            error_log("WP-CLI command failed: " . $result['output']);
        }
        
        return $result;
    }
    
    /**
     * Check if WordPress is installed
     */
    public function isWordPressInstalled($container, $user, $path = null) {
        if ($path === null) {
            $path = "/home/{$user}/public_html";
        }
        
        $result = $this->execWpCli($container, $user, "wp core is-installed", $path);
        return $result['success'];
    }
    
    /**
     * Get WordPress version
     */
    public function getWordPressVersion($container, $user, $path = null) {
        if ($path === null) {
            $path = "/home/{$user}/public_html";
        }
        
        $result = $this->execWpCli($container, $user, "wp core version", $path);
        if ($result['success']) {
            return trim($result['output']);
        }
        return null;
    }
    
    /**
     * Install WordPress
     */
    public function installWordPress($data) {
        // For site-based installation, extract data from site
        if (!empty($data['site_id'])) {
            $stmt = $this->db->prepare("
                SELECT s.*, 
                       ct.name as container_type_name,
                       sd.fqdn as primary_fqdn
                FROM sites s
                INNER JOIN container_types ct ON s.container_type_id = ct.id
                INNER JOIN site_domains sd ON s.id = sd.site_id AND sd.is_primary = 1
                WHERE s.id = ?
            ");
            $stmt->execute([$data['site_id']]);
            $site = $stmt->fetch(PDO::FETCH_ASSOC);
            
            if (!$site) {
                throw new Exception("Site not found");
            }
            
            // Use site data
            $data['user'] = $site['username'];
            $data['domain'] = $site['primary_fqdn'];
            // Container name format: domain-01 (matching existing containers)
            $data['container'] = $site['primary_fqdn'] . '-01';
            
            // Log for debugging
            error_log("WordPress Install - Site ID: {$data['site_id']}, User: {$data['user']}, Domain: {$data['domain']}, Container: {$data['container']}");
        }
        
        $required = ['container', 'user', 'domain', 'title', 'admin_username', 'admin_password', 'admin_email'];
        foreach ($required as $field) {
            if (empty($data[$field])) {
                throw new Exception("Missing required field: $field");
            }
        }
        
        $path = "/home/{$data['user']}/public_html";
        
        // Check if already installed
        if ($this->isWordPressInstalled($data['container'], $data['user'], $path)) {
            throw new Exception("WordPress is already installed at this location");
        }
        
        // Download WordPress core (skip if already present)
        $result = $this->execWpCli($data['container'], $data['user'], "wp core download --skip-content", $path);
        if (!$result['success']) {
            // If files already exist, that's okay
            if (strpos($result['output'], 'already be present') === false) {
                throw new Exception("Failed to download WordPress: " . $result['output']);
            }
            error_log("WordPress Install: WordPress files already present, continuing with installation");
        }
        
        // Create wp-config.php with unique database and user names
        $randomSuffix = substr(bin2hex(random_bytes(4)), 0, 8); // 8 random characters
        $dbName = $data['db_name'] ?? $data['user'] . '_' . str_replace('.', '_', $data['domain']) . '_wp_' . $randomSuffix;
        $dbUser = $data['db_user'] ?? $data['user'] . '_wp_' . $randomSuffix;
        $dbPass = $data['db_password'] ?? $this->generatePassword();
        $dbHost = $data['db_host'] ?? 'mysql';
        
        // Create database if needed
        if ($data['create_database'] ?? true) {
            $mysqlMgmt = new \mysqlmgmt();
            
            error_log("WordPress Install: Creating DB user '$dbUser' and database '$dbName'");
            
            // First ensure the MySQL user exists
            $userResult = $mysqlMgmt->createMySQLUser($dbUser, $dbPass);
            if ($userResult['status'] !== '0' && strpos($userResult['msg'], 'already exists') === false) {
                throw new Exception("Failed to create MySQL user: " . $userResult['msg']);
            }
            
            // Then create the database 
            $dbResult = $mysqlMgmt->createDatabase($dbName, $dbUser);
            if ($dbResult['status'] !== '0') {
                // If database already exists, that's okay for WordPress installation
                if (strpos($dbResult['msg'], 'already exists') === false) {
                    throw new Exception("Failed to create database: " . $dbResult['msg']);
                }
                error_log("WordPress Install: Database $dbName already exists, continuing with installation");
            }
        }
        
        // Create wp-config
        $configCmd = sprintf(
            "wp config create --dbname=%s --dbuser=%s --dbpass=%s --dbhost=%s",
            escapeshellarg($dbName),
            escapeshellarg($dbUser),
            escapeshellarg($dbPass),
            escapeshellarg($dbHost)
        );
        
        $result = $this->execWpCli($data['container'], $data['user'], $configCmd, $path);
        if (!$result['success']) {
            throw new Exception("Failed to create wp-config.php: " . $result['output']);
        }
        
        // Install WordPress
        $installCmd = sprintf(
            "wp core install --url=%s --title=%s --admin_user=%s --admin_password=%s --admin_email=%s",
            escapeshellarg($data['domain']),
            escapeshellarg($data['title']),
            escapeshellarg($data['admin_username']),
            escapeshellarg($data['admin_password']),
            escapeshellarg($data['admin_email'])
        );
        
        $result = $this->execWpCli($data['container'], $data['user'], $installCmd, $path);
        if (!$result['success']) {
            throw new Exception("Failed to install WordPress: " . $result['output']);
        }
        
        // Install wp-cli-login-command plugin for auto-login functionality
        $loginPluginCmd = "wp package install aaemnnosttv/wp-cli-login-command";
        $loginResult = $this->execWpCli($data['container'], $data['user'], $loginPluginCmd, $path);
        if (!$loginResult['success']) {
            // Log warning but don't fail the installation
            error_log("Warning: Failed to install wp-cli-login-command: " . $loginResult['output']);
        }
        
        // Save site information to database
        $stmt = $this->db->prepare("
            INSERT INTO wordpress_sites 
            (user, domain, container_name, admin_email, admin_username, wp_version, preferred_backup_target_id) 
            VALUES (?, ?, ?, ?, ?, ?, ?)
        ");
        
        $version = $this->getWordPressVersion($data['container'], $data['user'], $path);
        // Handle backup target ID - convert empty string to null
        $backupTargetId = null;
        if (!empty($data['backup_target_id']) && is_numeric($data['backup_target_id'])) {
            $backupTargetId = (int)$data['backup_target_id'];
        }
        
        $stmt->execute([
            $data['user'],
            $data['domain'],
            $data['container'],
            $data['admin_email'],
            $data['admin_username'],
            $version,
            $backupTargetId
        ]);
        
        $siteId = $this->db->lastInsertId();
        
        // Set up basic security settings
        $this->applySecurityHardening($siteId, $data['container'], $data['user']);
        
        return [
            'success' => true,
            'site_id' => $siteId,
            'db_name' => $dbName,
            'db_user' => $dbUser,
            'db_password' => $dbPass
        ];
    }
    
    /**
     * Update WordPress core
     */
    public function updateCore($siteId) {
        $site = $this->getSite($siteId);
        if (!$site) {
            throw new Exception("Site not found");
        }
        
        // Record update start
        $updateId = $this->recordUpdateStart($siteId, 'core', 'WordPress Core', $site['wp_version']);
        
        try {
            // Perform the update directly
            $result = $this->performCoreUpdateBackground($siteId, $updateId);
            
            return [
                'success' => true, 
                'message' => 'WordPress core update completed successfully',
                'update_id' => $updateId,
                'status' => 'completed',
                'new_version' => $result['new_version'] ?? null,
                'backup_results' => $result['backup_results'] ?? null
            ];
            
        } catch (Exception $e) {
            // Record failure
            $this->recordUpdateFailed($updateId, $e->getMessage());
            
            return [
                'success' => false,
                'message' => 'WordPress core update failed: ' . $e->getMessage(),
                'update_id' => $updateId,
                'status' => 'failed'
            ];
        }
    }
    
    /**
     * Perform WordPress core update in background
     */
    public function performCoreUpdateBackground($siteId, $updateId) {
        $site = $this->getSite($siteId);
        if (!$site) {
            throw new Exception("Site not found");
        }
        
        $backupResults = [];
        
        // Create backup if enabled
        if ($site['auto_backup_before_update']) {
            try {
                $backupResults = $this->createBackup($site, 'pre-update');
                error_log("WordPress Update: Backup created for site {$siteId}");
            } catch (Exception $e) {
                // Log the error but continue with update
                error_log("WordPress Update: Failed to create backup: " . $e->getMessage());
                // For critical sites, you might want to stop here:
                // throw new Exception("Failed to create pre-update backup: " . $e->getMessage());
            }
        }
        
        try {
            // Update WordPress core
            $result = $this->execWpCli($site['container_name'], $site['user'], "wp core update");
            if (!$result['success']) {
                throw new Exception("Core update failed: " . $result['output']);
            }
            
            // Update database if needed
            $result = $this->execWpCli($site['container_name'], $site['user'], "wp core update-db");
            
            // Get new version
            $newVersion = $this->getWordPressVersion($site['container_name'], $site['user']);
            
            // Update site record
            $stmt = $this->db->prepare("UPDATE wordpress_sites SET wp_version = ? WHERE id = ?");
            $stmt->execute([$newVersion, $siteId]);
            
            // Record success
            $this->recordUpdateComplete($updateId, $newVersion);
            
            return ['success' => true, 'new_version' => $newVersion, 'backup_results' => $backupResults];
            
        } catch (Exception $e) {
            // Record failure
            $this->recordUpdateFailed($updateId, $e->getMessage());
            
            // Check if site is broken
            if ($this->isSiteBroken($site)) {
                // Attempt rollback if backup exists
                if (!empty($backupResults)) {
                    error_log("WordPress Update: Site appears broken, attempting rollback for site {$siteId}");
                    $this->rollbackFromBackup($site, $backupResults);
                }
            }
            
            throw $e;
        }
    }
    
    /**
     * Get update status
     */
    public function getUpdateStatus($updateId) {
        $stmt = $this->db->prepare("
            SELECT * FROM wp_update_history 
            WHERE id = ?
        ");
        $stmt->execute([$updateId]);
        $update = $stmt->fetch(PDO::FETCH_ASSOC);
        
        if (!$update) {
            return ['error' => 'Update not found'];
        }
        
        return [
            'success' => true,
            'status' => $update['status'],
            'old_version' => $update['old_version'],
            'new_version' => $update['new_version'],
            'error_message' => $update['error_message'],
            'started_at' => $update['started_at'],
            'completed_at' => $update['completed_at']
        ];
    }
    
    /**
     * Apply security hardening
     */
    public function applySecurityHardening($siteId, $container = null, $user = null) {
        if (!$container || !$user) {
            $site = $this->getSite($siteId);
            $container = $site['container_name'];
            $user = $site['user'];
            $domain = $site['domain'];
        } else {
            // If container and user are provided, we still need domain
            $site = $this->getSite($siteId);
            $domain = $site['domain'];
        }
        
        // Get or create security settings
        $stmt = $this->db->prepare("
            INSERT INTO wp_security_settings (site_id) VALUES (?)
            ON DUPLICATE KEY UPDATE updated_at = NOW()
        ");
        $stmt->execute([$siteId]);
        
        // Disable file editor
        $this->execWpCli($container, $user, 
            "wp config set DISALLOW_FILE_EDIT true --raw"
        );
        
        // Set secure keys
        $this->execWpCli($container, $user, "wp config shuffle-salts");
        
        // Disable XML-RPC
        $htaccessRules = '
# Block XML-RPC
<Files xmlrpc.php>
Order Allow,Deny
Deny from all
</Files>

# Disable directory browsing
Options -Indexes

# Block PHP in uploads
<Directory "wp-content/uploads">
  <Files "*.php">
    Order Allow,Deny
    Deny from all
  </Files>
</Directory>
';
        
        // Add .htaccess rules
        $this->addHtaccessRules($container, $user, $domain, $htaccessRules);
        
        return ['success' => true];
    }
    
    /**
     * Import existing WordPress installation
     */
    public function importWordPress($data) {
        if (empty($data['site_id'])) {
            throw new Exception('Site ID is required');
        }
        
        $siteId = $data['site_id'];
        $site = $this->getRegularSite($siteId);
        if (!$site) {
            throw new Exception('Site not found');
        }
        
        // Check permissions
        if (AUTH_USER !== 'root' && $site['username'] !== AUTH_USER) {
            throw new Exception('Permission denied: You can only import WordPress for your own sites');
        }
        
        $container = $site['primary_fqdn'] . '-01';
        $user = $site['username'];
        $domain = $site['primary_fqdn'];
        $sitePath = "/home/{$user}/public_html";
        
        // Check if WordPress is installed
        $wpCheckResult = $this->execWpCli($container, $user, "wp core is-installed", $sitePath);
        if (!$wpCheckResult['success']) {
            throw new Exception('WordPress installation not found at ' . $sitePath);
        }
        
        // Get WordPress information
        $wpInfo = $this->getWordPressInfo($container, $user, $sitePath);
        
        // Get database information from wp-config.php
        $dbInfo = $this->getWordPressDatabaseInfo($container, $user, $sitePath);
        
        // Check if this site is already managed
        $existingWpSite = $this->getSiteByDomain($domain);
        if ($existingWpSite) {
            throw new Exception('WordPress site ' . $domain . ' is already being managed');
        }
        
        // Handle backup target ID - convert empty string to null
        $backupTargetId = null;
        if (!empty($data['import_backup_target_id']) && is_numeric($data['import_backup_target_id'])) {
            $backupTargetId = (int)$data['import_backup_target_id'];
        }
        
        // Create WordPress site record
        $stmt = $this->db->prepare("
            INSERT INTO wordpress_sites 
            (user, domain, container_name, site_path, admin_email, admin_username, wp_version, database_name, preferred_backup_target_id, status, created_at)
            VALUES (?, ?, ?, ?, ?, ?, ?, ?, ?, 'active', NOW())
        ");
        
        $stmt->execute([
            $user,
            $domain, 
            $container,
            $sitePath,
            $wpInfo['admin_email'] ?? '',
            $wpInfo['admin_user'] ?? '',
            $wpInfo['version'] ?? '',
            $dbInfo['name'] ?? '',
            $backupTargetId
        ]);
        
        $wpSiteId = $this->db->lastInsertId();
        
        // Create default security settings
        $this->createDefaultSecuritySettings($wpSiteId);
        
        // Install wp-cli-login-command plugin for auto-login functionality
        $loginPluginCmd = "wp package install aaemnnosttv/wp-cli-login-command";
        $loginResult = $this->execWpCli($container, $user, $loginPluginCmd, $sitePath);
        if (!$loginResult['success']) {
            // Log warning but don't fail the import
            error_log("Warning: Failed to install wp-cli-login-command during import: " . $loginResult['output']);
        }
        
        return [
            'success' => true,
            'message' => 'WordPress site imported successfully',
            'site_info' => $wpInfo,
            'database_info' => $dbInfo
        ];
    }
    
    /**
     * Get WordPress installation information
     */
    public function getWordPressInfo($container, $user, $sitePath = null) {
        // Default site path if not provided (for backward compatibility)
        if ($sitePath === null) {
            $sitePath = "/home/{$user}/public_html";
        }
        $info = [];
        
        // Get WordPress version
        $versionResult = $this->execWpCli($container, $user, "wp core version", $sitePath);
        if ($versionResult['success']) {
            $info['version'] = trim($versionResult['output']);
        }
        
        // Get site URL
        $urlResult = $this->execWpCli($container, $user, "wp option get siteurl", $sitePath);
        if ($urlResult['success']) {
            $info['site_url'] = trim($urlResult['output']);
        }
        
        // Get site title
        $titleResult = $this->execWpCli($container, $user, "wp option get blogname", $sitePath);
        if ($titleResult['success']) {
            $info['site_title'] = trim($titleResult['output']);
        }
        
        // Get admin email
        $emailResult = $this->execWpCli($container, $user, "wp option get admin_email", $sitePath);
        if ($emailResult['success']) {
            $info['admin_email'] = trim($emailResult['output']);
        }
        
        // Get admin user
        $adminResult = $this->execWpCli($container, $user, "wp user list --role=administrator --field=user_login --format=csv", $sitePath);
        if ($adminResult['success']) {
            $adminUsers = array_filter(explode("\n", trim($adminResult['output'])));
            if (!empty($adminUsers)) {
                $info['admin_user'] = $adminUsers[0];
            }
        }
        
        // Get theme info
        $themeResult = $this->execWpCli($container, $user, "wp theme list --status=active --format=json", $sitePath);
        if ($themeResult['success']) {
            $themes = json_decode($themeResult['output'], true);
            if (!empty($themes)) {
                $info['active_theme'] = $themes[0]['name'];
            }
        }
        
        // Get plugin count
        $pluginResult = $this->execWpCli($container, $user, "wp plugin list --status=active --format=count", $sitePath);
        if ($pluginResult['success']) {
            $info['active_plugins'] = intval(trim($pluginResult['output']));
        }
        
        // Get database configuration (for backward compatibility)
        $dbNameResult = $this->execWpCli($container, $user, "wp config get DB_NAME", $sitePath);
        if ($dbNameResult['success']) {
            $info['db_name'] = trim($dbNameResult['output']);
        }
        
        $dbUserResult = $this->execWpCli($container, $user, "wp config get DB_USER", $sitePath);
        if ($dbUserResult['success']) {
            $info['db_user'] = trim($dbUserResult['output']);
        }
        
        return $info;
    }
    
    /**
     * Get WordPress database information from wp-config.php
     */
    private function getWordPressDatabaseInfo($container, $user, $sitePath) {
        $info = [];
        
        // Get database name
        $dbNameResult = $this->execWpCli($container, $user, "wp config get DB_NAME", $sitePath);
        if ($dbNameResult['success']) {
            $info['name'] = trim($dbNameResult['output']);
        }
        
        // Get database user
        $dbUserResult = $this->execWpCli($container, $user, "wp config get DB_USER", $sitePath);
        if ($dbUserResult['success']) {
            $info['user'] = trim($dbUserResult['output']);
        }
        
        // Get database host
        $dbHostResult = $this->execWpCli($container, $user, "wp config get DB_HOST", $sitePath);
        if ($dbHostResult['success']) {
            $info['host'] = trim($dbHostResult['output']);
        }
        
        // Get table prefix
        $prefixResult = $this->execWpCli($container, $user, "wp config get table_prefix", $sitePath);
        if ($prefixResult['success']) {
            $info['prefix'] = trim($prefixResult['output']);
        }
        
        return $info;
    }
    
    /**
     * Get site by domain
     */
    private function getSiteByDomain($domain) {
        $stmt = $this->db->prepare("SELECT * FROM wordpress_sites WHERE domain = ?");
        $stmt->execute([$domain]);
        return $stmt->fetch(PDO::FETCH_ASSOC);
    }
    
    /**
     * Remove WordPress site from management
     */
    public function removeFromManagement($siteId) {
        $site = $this->getSite($siteId);
        if (!$site) {
            throw new Exception("WordPress site not found");
        }
        
        // Check permissions
        if (AUTH_USER !== 'root' && $site['user'] !== AUTH_USER) {
            throw new Exception("Permission denied: You can only remove your own WordPress sites from management");
        }
        
        // Remove the WordPress site record and all related data
        $this->db->beginTransaction();
        
        try {
            // Remove security settings
            $stmt = $this->db->prepare("DELETE FROM wp_security_settings WHERE site_id = ?");
            $stmt->execute([$siteId]);
            
            // Remove login tokens
            $stmt = $this->db->prepare("DELETE FROM wp_login_tokens WHERE site_id = ?");
            $stmt->execute([$siteId]);
            
            // Remove site plugins
            $stmt = $this->db->prepare("DELETE FROM wp_site_plugins WHERE site_id = ?");
            $stmt->execute([$siteId]);
            
            // Remove update history
            $stmt = $this->db->prepare("DELETE FROM wp_update_history WHERE site_id = ?");
            $stmt->execute([$siteId]);
            
            // Remove the main WordPress site record
            $stmt = $this->db->prepare("DELETE FROM wordpress_sites WHERE id = ?");
            $stmt->execute([$siteId]);
            
            $this->db->commit();
            
            return [
                'success' => true,
                'message' => 'WordPress site removed from management successfully. Files and databases remain unchanged.'
            ];
            
        } catch (Exception $e) {
            $this->db->rollback();
            throw new Exception("Failed to remove WordPress site from management: " . $e->getMessage());
        }
    }
    
    /**
     * Reset admin password
     */
    public function resetAdminPassword($siteId, $newPassword = null) {
        $site = $this->getSite($siteId);
        if (!$site) {
            throw new Exception("Site not found");
        }
        
        if (!$newPassword) {
            $newPassword = $this->generatePassword();
        }
        
        $result = $this->execWpCli(
            $site['container_name'], 
            $site['user'],
            sprintf("wp user update %s --user_pass=%s", 
                escapeshellarg($site['admin_username']),
                escapeshellarg($newPassword)
            )
        );
        
        if (!$result['success']) {
            throw new Exception("Failed to reset password: " . $result['output']);
        }
        
        return ['success' => true, 'password' => $newPassword];
    }
    
    /**
     * Create one-time login token
     */
    public function createLoginToken($siteId) {
        $site = $this->getSite($siteId);
        if (!$site) {
            throw new Exception("Site not found");
        }
        
        // Check permissions
        if (AUTH_USER !== 'root' && $site['user'] !== AUTH_USER) {
            throw new Exception("Permission denied: You can only create login tokens for your own WordPress sites");
        }
        
        $path = "/home/{$site['user']}/public_html";
        
        // Use the admin username from the database
        $adminUsername = $site['admin_username'];
        if (empty($adminUsername)) {
            throw new Exception("No admin username found for this WordPress site");
        }
        
        // Create magic login link using wp-cli-login-command plugin
        $cmd = "wp login create " . escapeshellarg($adminUsername);
        $result = $this->execWpCli($site['container_name'], $site['user'], $cmd, $path);
        
        if (!$result['success']) {
            throw new Exception("Failed to create login link: " . $result['output']);
        }
        
        // Parse the output to extract the login URL
        $output = $result['output'];
        $lines = explode("\n", $output);
        $loginUrl = null;
        
        foreach ($lines as $line) {
            $line = trim($line);
            // Look for URLs that start with http
            if (preg_match('/^https?:\/\//', $line)) {
                $loginUrl = $line;
                break;
            }
        }
        
        if (!$loginUrl) {
            throw new Exception("Could not extract login URL from wp-cli output: " . $output);
        }
        
        return [
            'success' => true,
            'login_url' => $loginUrl,
            'expires_at' => date('Y-m-d H:i:s', time() + 900), // wp-cli-login-command expires in 15 minutes
            'message' => 'Magic login link created successfully. Link expires in 15 minutes or after first use.'
        ];
    }
    
    /**
     * Clone site to staging
     */
    public function cloneToStaging($siteId, $stagingDomain, $stagingContainer) {
        $site = $this->getSite($siteId);
        if (!$site) {
            throw new Exception("Site not found");
        }
        
        // Check if user has enough resources
        if (!$this->checkUserResources($site['user'], 'staging')) {
            throw new Exception("Insufficient resources for staging site");
        }
        
        // Create staging database
        $stagingDb = str_replace('.', '_', $stagingDomain) . '_staging';
        $mysqlMgmt = new \mysqlmgmt();
        $dbResult = $mysqlMgmt->createDatabase($stagingDb, $site['user'], $this->generatePassword());
        
        if ($dbResult['status'] !== '0') {
            throw new Exception("Failed to create staging database: " . $dbResult['msg']);
        }
        
        // Export production database
        $exportResult = $this->execWpCli(
            $site['container_name'],
            $site['user'],
            "wp db export --add-drop-table /tmp/staging-export.sql"
        );
        
        if (!$exportResult['success']) {
            throw new Exception("Failed to export database: " . $exportResult['output']);
        }
        
        // Copy files to staging
        $prodPath = "/home/{$site['user']}/public_html";
        $stagingPath = "/home/{$site['user']}/staging";
        
        $copyCmd = sprintf(
            "docker exec %s cp -a %s %s",
            escapeshellarg($site['container_name']),
            escapeshellarg($prodPath),
            escapeshellarg($stagingPath)
        );
        
        exec($copyCmd, $output, $returnCode);
        if ($returnCode !== 0) {
            throw new Exception("Failed to copy files to staging");
        }
        
        // Update wp-config for staging
        $configResult = $this->execWpCli(
            $stagingContainer,
            $site['user'],
            sprintf("wp config set DB_NAME %s", escapeshellarg($stagingDb)),
            $stagingPath
        );
        
        // Import database to staging
        $importResult = $this->execWpCli(
            $stagingContainer,
            $site['user'],
            "wp db import /tmp/staging-export.sql",
            $stagingPath
        );
        
        // Search and replace URLs
        $this->searchReplace(
            $stagingContainer,
            $site['user'],
            $site['domain'],
            $stagingDomain,
            $stagingPath
        );
        
        // Create staging site record
        $stmt = $this->db->prepare("
            INSERT INTO wordpress_sites 
            (user, domain, container_name, site_path, wp_version, is_staging, parent_site_id, 
             admin_email, admin_username) 
            VALUES (?, ?, ?, ?, ?, 1, ?, ?, ?)
        ");
        
        $stmt->execute([
            $site['user'],
            $stagingDomain,
            $stagingContainer,
            $stagingPath,
            $site['wp_version'],
            $siteId,
            $site['admin_email'],
            $site['admin_username']
        ]);
        
        return [
            'success' => true,
            'staging_id' => $this->db->lastInsertId(),
            'staging_url' => "https://{$stagingDomain}"
        ];
    }
    
    /**
     * Search and replace in database
     */
    public function searchReplace($container, $user, $search, $replace, $path = null) {
        if ($path === null) {
            $path = "/home/{$user}/public_html";
        }
        
        $cmd = sprintf(
            "wp search-replace %s %s --all-tables --precise",
            escapeshellarg($search),
            escapeshellarg($replace)
        );
        
        $result = $this->execWpCli($container, $user, $cmd, $path);
        
        if (!$result['success']) {
            throw new Exception("Search and replace failed: " . $result['output']);
        }
        
        return ['success' => true, 'output' => $result['output']];
    }
    
    /**
     * Get list of WP-CLI enabled container types
     */
    public function getWpCliContainerTypes() {
        $stmt = $this->db->query("
            SELECT ct.*, wcc.is_active as wp_cli_enabled 
            FROM container_types ct
            LEFT JOIN wp_cli_containers wcc ON ct.name = wcc.container_image
            WHERE ct.active = 1
            ORDER BY ct.name
        ");
        return $stmt->fetchAll(PDO::FETCH_ASSOC);
    }
    
    /**
     * Update WP-CLI support for container types (root only)
     */
    public function updateWpCliSupport($containerTypeName, $enabled) {
        if ($enabled) {
            $stmt = $this->db->prepare("
                INSERT INTO wp_cli_containers (container_image, is_active) 
                VALUES (?, 1)
                ON DUPLICATE KEY UPDATE is_active = 1
            ");
            $stmt->execute([$containerTypeName]);
        } else {
            $stmt = $this->db->prepare("
                UPDATE wp_cli_containers SET is_active = 0 
                WHERE container_image = ?
            ");
            $stmt->execute([$containerTypeName]);
        }
        return ['success' => true];
    }
    
    /**
     * Get user sites that use WP-CLI enabled containers
     */
    public function getUserWordPressSites($user) {
        $userFilter = $user === 'root' ? '' : 'AND s.username = :user';
        
        $sql = "
            SELECT s.*, 
                   ct.name as container_type_name, 
                   ct.description as container_description,
                   sd.fqdn as primary_fqdn
            FROM sites s
            INNER JOIN container_types ct ON s.container_type_id = ct.id
            INNER JOIN site_domains sd ON s.id = sd.site_id AND sd.is_primary = 1
            INNER JOIN wp_cli_containers wcc ON ct.name = wcc.container_image
            LEFT JOIN wordpress_sites ws ON sd.fqdn = ws.domain
            WHERE wcc.is_active = 1 
            AND s.active = 1
            AND ws.id IS NULL
            {$userFilter}
            ORDER BY s.username, s.site_name
        ";
        
        $stmt = $this->db->prepare($sql);
        if ($user !== 'root') {
            $stmt->bindParam(':user', $user);
        }
        $stmt->execute();
        
        return $stmt->fetchAll(PDO::FETCH_ASSOC);
    }
    
    /**
     * Check if WordPress is already installed on a site
     */
    public function checkWordPressInstallation($siteId) {
        // Get site info
        $stmt = $this->db->prepare("
            SELECT s.*, 
                   ct.name as container_type_name,
                   sd.fqdn as primary_fqdn
            FROM sites s
            INNER JOIN container_types ct ON s.container_type_id = ct.id
            INNER JOIN site_domains sd ON s.id = sd.site_id AND sd.is_primary = 1
            WHERE s.id = ?
        ");
        $stmt->execute([$siteId]);
        $site = $stmt->fetch(PDO::FETCH_ASSOC);
        
        if (!$site) {
            return ['exists' => false, 'error' => 'Site not found'];
        }
        
        $containerName = $site['primary_fqdn'] . '-01';
        $isInstalled = $this->isWordPressInstalled($containerName, $site['username']);
        
        $result = ['exists' => $isInstalled, 'site' => $site];
        
        if ($isInstalled) {
            // Get WordPress info
            $result['wp_version'] = $this->getWordPressVersion($containerName, $site['username']);
            
            // Try to get database info, admin user, etc.
            $wpInfo = $this->getWordPressInfo($containerName, $site['username']);
            $result = array_merge($result, $wpInfo);
        }
        
        return $result;
    }
    
    /**
     * Update backup settings for a WordPress site
     */
    public function updateBackupSettings($siteId, $backupTargetId, $autoBackup) {
        $site = $this->getSite($siteId);
        if (!$site) {
            throw new Exception("Site not found");
        }
        
        // Update backup settings
        $stmt = $this->db->prepare("
            UPDATE wordpress_sites 
            SET preferred_backup_target_id = ?, 
                auto_backup_before_update = ? 
            WHERE id = ?
        ");
        
        $stmt->execute([
            $backupTargetId ?: null,
            $autoBackup ? 1 : 0,
            $siteId
        ]);
        
        return ['success' => true];
    }
    
    /**
     * Get recommended plugins
     */
    public function getRecommendedPlugins() {
        $stmt = $this->db->query("
            SELECT * FROM wp_recommended_plugins 
            WHERE is_active = 1 
            ORDER BY sort_order, name
        ");
        return $stmt->fetchAll(PDO::FETCH_ASSOC);
    }
    
    /**
     * Install plugin from recommendation
     */
    public function installRecommendedPlugin($siteId, $pluginSlug) {
        $site = $this->getSite($siteId);
        if (!$site) {
            throw new Exception("Site not found");
        }
        
        // Check if plugin exists in recommendations
        $stmt = $this->db->prepare("
            SELECT * FROM wp_recommended_plugins 
            WHERE slug = ? AND is_active = 1
        ");
        $stmt->execute([$pluginSlug]);
        $plugin = $stmt->fetch(PDO::FETCH_ASSOC);
        
        if (!$plugin) {
            throw new Exception("Plugin not found in recommendations");
        }
        
        // Install plugin
        $result = $this->execWpCli(
            $site['container_name'],
            $site['user'],
            sprintf("wp plugin install %s --activate", escapeshellarg($plugin['install_url']))
        );
        
        if (!$result['success']) {
            throw new Exception("Failed to install plugin: " . $result['output']);
        }
        
        // Record installation
        $stmt = $this->db->prepare("
            INSERT INTO wp_site_plugins 
            (site_id, plugin_slug, plugin_name, is_active) 
            VALUES (?, ?, ?, 1)
            ON DUPLICATE KEY UPDATE 
            is_active = 1,
            last_updated = NOW()
        ");
        $stmt->execute([$siteId, $pluginSlug, $plugin['name']]);
        
        return ['success' => true];
    }
    
    // Helper methods
    
    private function getSite($siteId) {
        $stmt = $this->db->prepare("SELECT * FROM wordpress_sites WHERE id = ?");
        $stmt->execute([$siteId]);
        return $stmt->fetch(PDO::FETCH_ASSOC);
    }
    
    private function getRegularSite($siteId) {
        $stmt = $this->db->prepare("
            SELECT s.*, 
                   ct.name as container_type_name,
                   sd.fqdn as primary_fqdn,
                   sd.fqdn as domain
            FROM sites s
            INNER JOIN container_types ct ON s.container_type_id = ct.id
            INNER JOIN site_domains sd ON s.id = sd.site_id AND sd.is_primary = 1
            WHERE s.id = ?
        ");
        $stmt->execute([$siteId]);
        return $stmt->fetch(PDO::FETCH_ASSOC);
    }
    
    private function createDefaultSecuritySettings($siteId) {
        $stmt = $this->db->prepare("
            INSERT INTO wp_security_settings (
                site_id, 
                disable_file_editor, 
                disable_xmlrpc, 
                hide_wp_version, 
                disable_directory_browsing, 
                limit_login_attempts,
                database_prefix
            ) VALUES (?, TRUE, TRUE, FALSE, TRUE, TRUE, 'wp_')
        ");
        $stmt->execute([$siteId]);
    }
    
    private function generatePassword($length = 16) {
        $chars = 'abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ0123456789!@#$%^&*()';
        $password = '';
        for ($i = 0; $i < $length; $i++) {
            $password .= $chars[random_int(0, strlen($chars) - 1)];
        }
        return $password;
    }
    
    private function addHtaccessRules($container, $user, $domain, $rules) {
        $path = "/home/{$user}/{$domain}/public_html";
        $htaccessPath = "{$path}/.htaccess";
        
        // Use cat with here-document for multi-line content
        $cmd = sprintf(
            "cat >> %s << 'EOF'\n%s\nEOF",
            escapeshellarg($htaccessPath),
            $rules
        );
        
        $result = $this->execWpCli($container, $user, $cmd, $path);
        return $result['success'];
    }
    
    private function recordUpdateStart($siteId, $type, $itemName, $oldVersion) {
        $stmt = $this->db->prepare("
            INSERT INTO wp_update_history 
            (site_id, update_type, item_name, old_version, status) 
            VALUES (?, ?, ?, ?, 'in_progress')
        ");
        $stmt->execute([$siteId, $type, $itemName, $oldVersion]);
        return $this->db->lastInsertId();
    }
    
    private function recordUpdateComplete($updateId, $newVersion) {
        $stmt = $this->db->prepare("
            UPDATE wp_update_history 
            SET status = 'completed', new_version = ?, completed_at = NOW() 
            WHERE id = ?
        ");
        $stmt->execute([$newVersion, $updateId]);
    }
    
    private function recordUpdateFailed($updateId, $error) {
        $stmt = $this->db->prepare("
            UPDATE wp_update_history 
            SET status = 'failed', error_message = ?, completed_at = NOW() 
            WHERE id = ?
        ");
        $stmt->execute([$error, $updateId]);
    }
    
    private function isSiteBroken($site) {
        // Check if site returns 500 error or white screen
        $url = "https://{$site['domain']}";
        $ch = curl_init($url);
        curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);
        curl_setopt($ch, CURLOPT_TIMEOUT, 10);
        curl_setopt($ch, CURLOPT_SSL_VERIFYPEER, false);
        
        curl_exec($ch);
        $httpCode = curl_getinfo($ch, CURLINFO_HTTP_CODE);
        curl_close($ch);
        
        return $httpCode >= 500;
    }
    
    private function createBackup($site, $type = 'manual') {
        // Use existing backup system - need to get target ID first
        $mysql = new \mysqlmgmt();
        $db = $mysql->getMySQLConnection();
        $db->exec("USE whp");
        
        // Check if site has a preferred backup target
        if (!empty($site['preferred_backup_target_id'])) {
            // Verify the user has access to this target
            $stmt = $db->prepare("
                SELECT id, name, type 
                FROM backup_targets 
                WHERE id = ? 
                AND (owner = ? OR is_global = 1)
                LIMIT 1
            ");
            $stmt->execute([$site['preferred_backup_target_id'], $site['user']]);
            $target = $stmt->fetch(PDO::FETCH_ASSOC);
            
            if ($target) {
                $targetId = $target['id'];
                error_log("WordPress Backup: Using preferred backup target '{$target['name']}' (ID: {$targetId}, Type: {$target['type']}) for user {$site['user']}");
            } else {
                // Fall back to any available backup target
                $stmt = $db->prepare("
                    SELECT id, name, type 
                    FROM backup_targets 
                    WHERE (owner = ? OR is_global = 1) 
                    AND type != 'local'
                    ORDER BY 
                        CASE WHEN owner = ? THEN 0 ELSE 1 END,  -- Prefer user's own targets
                        id ASC
                    LIMIT 1
                ");
                $stmt->execute([$site['user'], $site['user']]);
                $target = $stmt->fetch(PDO::FETCH_ASSOC);
                
                if (!$target) {
                    // No backup targets available for this user
                    throw new Exception("No backup targets configured. Please configure a backup target in the Backups section first.");
                }
                
                $targetId = $target['id'];
                error_log("WordPress Backup: Using backup target '{$target['name']}' (ID: {$targetId}, Type: {$target['type']}) for user {$site['user']}");
            }
        }
        
        // Queue site backup (files)
        $this->queueBackup($targetId, $site['user'], 'site', $site['domain']);
        
        // Also queue the WordPress database backup
        try {
            // First try to get database name from our site record
            $dbName = !empty($site['database_name']) ? $site['database_name'] : null;
            
            // If not in database, get it from wp-config.php and update our record
            if (!$dbName) {
                $dbName = $this->getWordPressDatabaseName($site['container_name'], $site['user']);
                if ($dbName) {
                    // Update the site record with the database name for future use
                    $stmt = $this->db->prepare("UPDATE wordpress_sites SET database_name = ? WHERE id = ?");
                    $stmt->execute([$dbName, $site['id']]);
                }
            }
            
            if ($dbName) {
                $this->queueBackup($targetId, $site['user'], 'database', $dbName);
                
                return [
                    'success' => true,
                    'message' => "Queued WordPress site and database backups"
                ];
            } else {
                error_log("WordPress Backup: Could not determine database name for site {$site['domain']}");
            }
        } catch (Exception $e) {
            error_log("WordPress Backup: Could not queue database backup: " . $e->getMessage());
        }
        
        return [
            'success' => true,
            'message' => "Queued WordPress site backup"
        ];
    }
    
    private function queueBackup($targetId, $user, $backupType, $backupName) {
        // Add backup to queue for processing by the cron job
        $stmt = $this->db->prepare("
            INSERT INTO backup_queue 
            (target_id, user, backup_type, backup_name, priority, status) 
            VALUES (?, ?, ?, ?, 'high', 'queued')
        ");
        
        $stmt->execute([$targetId, $user, $backupType, $backupName]);
        
        error_log("WordPress Backup: Queued $backupType backup '$backupName' for user $user (target: $targetId)");
        
        return $this->db->lastInsertId();
    }
    
    private function getWordPressDatabaseName($container, $user) {
        // Get database name from wp-config.php
        $result = $this->execWpCli($container, $user, "wp config get DB_NAME");
        if ($result['success']) {
            return trim($result['output']);
        }
        return null;
    }
    
    private function rollbackFromBackup($site, $backupId) {
        // Implement backup restoration
        // This would restore files and database from backup
        error_log("Attempting to rollback site {$site['id']} from backup {$backupId}");
        // TODO: Implement actual rollback
    }
    
    private function checkUserResources($user, $resourceType) {
        // Check if user has enough disk space, sites allowed, etc.
        // For now, return true
        return true;
    }
    
    
    /**
     * Update auto-update settings for a WordPress site
     */
    public function updateAutoUpdateSettings($siteId, $updateType, $enabled) {
        // Validate inputs
        $validTypes = ['core', 'plugins', 'themes'];
        if (!in_array($updateType, $validTypes)) {
            throw new Exception("Invalid update type. Must be: " . implode(', ', $validTypes));
        }
        
        $site = $this->getSite($siteId);
        if (!$site) {
            throw new Exception("Site not found");
        }
        
        // Check if user has permission to manage this site
        if (AUTH_USER !== 'root' && $site['user'] !== AUTH_USER) {
            throw new Exception("Permission denied: You can only manage your own WordPress sites");
        }
        
        // Update the database
        $columnName = "auto_update_" . $updateType;
        $enabledValue = $enabled ? 1 : 0; // Ensure it's explicitly 1 or 0
        $stmt = $this->db->prepare("UPDATE wordpress_sites SET {$columnName} = ? WHERE id = ?");
        $stmt->execute([$enabledValue, $siteId]);
        
        if ($stmt->rowCount() === 0) {
            throw new Exception("Failed to update auto-update settings");
        }
        
        return ['success' => true, 'message' => "Auto-update setting for {$updateType} updated successfully"];
    }
    
    /**
     * Execute WP-CLI command (public wrapper for CLI script access)
     */
    public function executeWpCliCommand($container, $user, $command, $workDir = null) {
        return $this->execWpCli($container, $user, $command, $workDir);
    }
    
    /**
     * Get security settings for a WordPress site
     */
    public function getSecuritySettings($siteId) {
        $site = $this->getSite($siteId);
        if (!$site) {
            throw new Exception("Site not found");
        }
        
        // Check permissions
        if (AUTH_USER !== 'root' && $site['user'] !== AUTH_USER) {
            throw new Exception("Permission denied: You can only manage your own WordPress sites");
        }
        
        // Get security settings
        $stmt = $this->db->prepare("SELECT * FROM wp_security_settings WHERE site_id = ?");
        $stmt->execute([$siteId]);
        $settings = $stmt->fetch(PDO::FETCH_ASSOC);
        
        // If no settings exist, create default ones
        if (!$settings) {
            $stmt = $this->db->prepare("
                INSERT INTO wp_security_settings (
                    site_id, disable_file_editor, disable_xmlrpc, hide_wp_version, 
                    disable_directory_browsing, limit_login_attempts, security_headers_enabled,
                    block_php_uploads, force_strong_passwords
                ) VALUES (?, TRUE, TRUE, FALSE, TRUE, TRUE, TRUE, TRUE, FALSE)
            ");
            $stmt->execute([$siteId]);
            
            // Fetch the newly created settings
            $stmt = $this->db->prepare("SELECT * FROM wp_security_settings WHERE site_id = ?");
            $stmt->execute([$siteId]);
            $settings = $stmt->fetch(PDO::FETCH_ASSOC);
        }
        
        return ['success' => true, 'settings' => $settings];
    }
    
    /**
     * Update security settings for a WordPress site
     */
    public function updateSecuritySettings($siteId, $data) {
        $site = $this->getSite($siteId);
        if (!$site) {
            throw new Exception("Site not found");
        }
        
        // Check permissions
        if (AUTH_USER !== 'root' && $site['user'] !== AUTH_USER) {
            throw new Exception("Permission denied: You can only manage your own WordPress sites");
        }
        
        // Prepare security settings  
        $settings = [
            'disable_file_editor' => isset($data['disable_file_editor']) ? 1 : 0,
            'disable_xmlrpc' => isset($data['disable_xmlrpc']) ? 1 : 0,
            'hide_wp_version' => isset($data['hide_wp_version']) ? 1 : 0,
            'disable_directory_browsing' => isset($data['disable_directory_browsing']) ? 1 : 0,
            'limit_login_attempts' => isset($data['limit_login_attempts']) ? 1 : 0,
            'security_headers_enabled' => isset($data['security_headers_enabled']) ? 1 : 0,
            'block_php_uploads' => isset($data['block_php_uploads']) ? 1 : 0,
            'force_strong_passwords' => isset($data['force_strong_passwords']) ? 1 : 0
        ];
        
        // Update or insert security settings
        $stmt = $this->db->prepare("
            INSERT INTO wp_security_settings (
                site_id, disable_file_editor, disable_xmlrpc, hide_wp_version,
                disable_directory_browsing, limit_login_attempts, security_headers_enabled,
                block_php_uploads, force_strong_passwords
            ) VALUES (?, ?, ?, ?, ?, ?, ?, ?, ?)
            ON DUPLICATE KEY UPDATE
                disable_file_editor = VALUES(disable_file_editor),
                disable_xmlrpc = VALUES(disable_xmlrpc),
                hide_wp_version = VALUES(hide_wp_version),
                disable_directory_browsing = VALUES(disable_directory_browsing),
                limit_login_attempts = VALUES(limit_login_attempts),
                security_headers_enabled = VALUES(security_headers_enabled),
                block_php_uploads = VALUES(block_php_uploads),
                force_strong_passwords = VALUES(force_strong_passwords),
                updated_at = NOW()
        ");
        
        $stmt->execute([
            $siteId,
            $settings['disable_file_editor'],
            $settings['disable_xmlrpc'],
            $settings['hide_wp_version'],
            $settings['disable_directory_browsing'],
            $settings['limit_login_attempts'],
            $settings['security_headers_enabled'],
            $settings['block_php_uploads'],
            $settings['force_strong_passwords']
        ]);
        
        // Apply security measures to WordPress
        $this->applySecurity($siteId, $site, $settings);
        
        return ['success' => true, 'message' => 'Security settings applied successfully'];
    }
    
    /**
     * Apply security measures based on settings
     */
    private function applySecurity($siteId, $site, $settings) {
        $container = $site['container_name'];
        $user = $site['user'];
        $domain = $site['domain'];
        
        // Disable file editor
        if ($settings['disable_file_editor']) {
            $result = $this->execWpCli($container, $user, "wp config set DISALLOW_FILE_EDIT true --raw");
            if (!$result['success']) {
                error_log("Failed to set DISALLOW_FILE_EDIT: " . $result['output']);
            }
        } else {
            $result = $this->execWpCli($container, $user, "wp config delete DISALLOW_FILE_EDIT");
            if (!$result['success']) {
                error_log("Failed to delete DISALLOW_FILE_EDIT: " . $result['output']);
            }
        }
        
        // Hide WordPress version
        if ($settings['hide_wp_version']) {
            $this->execWpCli($container, $user, "wp config set WP_HIDE_VERSION true --raw");
        } else {
            $this->execWpCli($container, $user, "wp config delete WP_HIDE_VERSION");
        }
        
        // Force strong passwords
        if ($settings['force_strong_passwords']) {
            $this->execWpCli($container, $user, "wp config set FORCE_SSL_ADMIN true --raw");
        }
        
        // Build .htaccess rules
        $htaccessRules = '';
        
        // XML-RPC blocking
        if ($settings['disable_xmlrpc']) {
            $htaccessRules .= '
# Block XML-RPC
<Files xmlrpc.php>
Order Allow,Deny
Deny from all
</Files>
';
        }
        
        // Directory browsing
        if ($settings['disable_directory_browsing']) {
            $htaccessRules .= '
# Disable directory browsing
Options -Indexes
';
        }
        
        // Block PHP in uploads
        if ($settings['block_php_uploads']) {
            $htaccessRules .= '
# Block PHP in uploads
<Directory "wp-content/uploads">
  <Files "*.php">
    Order Allow,Deny
    Deny from all
  </Files>
</Directory>
';
        }
        
        // Security headers
        if ($settings['security_headers_enabled']) {
            $htaccessRules .= '
# Security headers
<IfModule mod_headers.c>
    Header always set X-Content-Type-Options nosniff
    Header always set X-Frame-Options DENY
    Header always set X-XSS-Protection "1; mode=block"
    Header always set Referrer-Policy "strict-origin-when-cross-origin"
</IfModule>
';
        }
        
        // Apply .htaccess rules if any
        if (!empty($htaccessRules)) {
            $this->addHtaccessRules($container, $user, $domain, $htaccessRules);
        }
    }
    
    /**
     * Shuffle WordPress security salts
     */
    public function shuffleSalts($siteId) {
        $site = $this->getSite($siteId);
        if (!$site) {
            throw new Exception("Site not found");
        }
        
        // Check permissions
        if (AUTH_USER !== 'root' && $site['user'] !== AUTH_USER) {
            throw new Exception("Permission denied: You can only manage your own WordPress sites");
        }
        
        $result = $this->execWpCli($site['container_name'], $site['user'], "wp config shuffle-salts");
        
        if (!$result['success']) {
            throw new Exception("Failed to shuffle salts: " . $result['output']);
        }
        
        return ['success' => true, 'message' => 'Security keys regenerated successfully'];
    }
    
    /**
     * Update .htaccess rules
     */
    public function updateHtaccessRules($siteId) {
        $site = $this->getSite($siteId);
        if (!$site) {
            throw new Exception("Site not found");
        }
        
        // Check permissions
        if (AUTH_USER !== 'root' && $site['user'] !== AUTH_USER) {
            throw new Exception("Permission denied: You can only manage your own WordPress sites");
        }
        
        // Get current security settings
        $stmt = $this->db->prepare("SELECT * FROM wp_security_settings WHERE site_id = ?");
        $stmt->execute([$siteId]);
        $settings = $stmt->fetch(PDO::FETCH_ASSOC);
        
        if ($settings) {
            $this->applySecurity($siteId, $site, $settings);
        }
        
        return ['success' => true, 'message' => '.htaccess rules updated successfully'];
    }
    
    /**
     * Perform basic security scan
     */
    public function performSecurityScan($siteId) {
        $site = $this->getSite($siteId);
        if (!$site) {
            throw new Exception("Site not found");
        }
        
        // Check permissions
        if (AUTH_USER !== 'root' && $site['user'] !== AUTH_USER) {
            throw new Exception("Permission denied: You can only manage your own WordPress sites");
        }
        
        $issues = [];
        $container = $site['container_name'];
        $user = $site['user'];
        
        // Check WordPress version
        $versionResult = $this->execWpCli($container, $user, "wp core check-update --format=json");
        if ($versionResult['success']) {
            $updates = json_decode($versionResult['output'], true);
            if (!empty($updates)) {
                $issues[] = "WordPress core updates available";
            }
        }
        
        // Check plugin updates
        $pluginResult = $this->execWpCli($container, $user, "wp plugin list --update=available --format=count");
        if ($pluginResult['success'] && trim($pluginResult['output']) > 0) {
            $issues[] = trim($pluginResult['output']) . " plugin updates available";
        }
        
        // Check admin user strength
        $adminResult = $this->execWpCli($container, $user, "wp user list --role=administrator --format=json");
        if ($adminResult['success']) {
            $admins = json_decode($adminResult['output'], true);
            foreach ($admins as $admin) {
                if (in_array($admin['user_login'], ['admin', 'administrator', 'root'])) {
                    $issues[] = "Weak admin username detected: " . $admin['user_login'];
                }
            }
        }
        
        // Check file permissions
        $permResult = $this->execWpCli($container, $user, "wp config get DISALLOW_FILE_EDIT");
        error_log("DISALLOW_FILE_EDIT check - Success: " . ($permResult['success'] ? 'true' : 'false') . ", Output: '" . trim($permResult['output']) . "'");
        
        if (!$permResult['success']) {
            $issues[] = "File editor not disabled (DISALLOW_FILE_EDIT constant not found)";
        } else {
            $output = trim($permResult['output']);
            // Accept 'true', '1', or 'TRUE' as valid values
            if (!in_array($output, ['true', '1', 'TRUE'])) {
                $issues[] = "File editor not disabled (DISALLOW_FILE_EDIT is '" . $output . "', should be 'true')";
            }
        }
        
        // Check for debug mode
        $debugResult = $this->execWpCli($container, $user, "wp config get WP_DEBUG");
        if ($debugResult['success'] && trim($debugResult['output']) === 'true') {
            $issues[] = "Debug mode is enabled (should be disabled in production)";
        }
        
        return ['success' => true, 'issues' => $issues];
    }
    
    // ========================================
    // RECOMMENDED PLUGINS MANAGEMENT METHODS
    // ========================================
    
    /**
     * Get all recommended plugins (for management interface)
     */
    public function getRecommendedPluginsForManagement() {
        $stmt = $this->db->query("
            SELECT id, slug, name, description, category, install_url, is_active, sort_order, created_at
            FROM wp_recommended_plugins 
            ORDER BY sort_order ASC, name ASC
        ");
        
        $plugins = $stmt->fetchAll(PDO::FETCH_ASSOC);
        
        // Convert boolean fields
        foreach ($plugins as &$plugin) {
            $plugin['is_active'] = (bool)$plugin['is_active'];
            $plugin['sort_order'] = (int)$plugin['sort_order'];
        }
        
        return $plugins;
    }
    
    /**
     * Get a single recommended plugin by ID
     */
    public function getRecommendedPlugin($pluginId) {
        $stmt = $this->db->prepare("
            SELECT id, slug, name, description, category, install_url, is_active, sort_order, created_at
            FROM wp_recommended_plugins 
            WHERE id = ?
        ");
        $stmt->execute([$pluginId]);
        
        $plugin = $stmt->fetch(PDO::FETCH_ASSOC);
        if (!$plugin) {
            throw new Exception('Plugin not found');
        }
        
        // Convert boolean fields
        $plugin['is_active'] = (bool)$plugin['is_active'];
        $plugin['sort_order'] = (int)$plugin['sort_order'];
        
        return $plugin;
    }
    
    /**
     * Add a new recommended plugin
     */
    public function addRecommendedPlugin($pluginData) {
        // Validate required fields
        if (empty($pluginData['name']) || empty($pluginData['slug'])) {
            throw new Exception('Plugin name and slug are required');
        }
        
        // Check if slug already exists
        $stmt = $this->db->prepare("SELECT id FROM wp_recommended_plugins WHERE slug = ?");
        $stmt->execute([$pluginData['slug']]);
        if ($stmt->fetch()) {
            throw new Exception('A plugin with this slug already exists');
        }
        
        $stmt = $this->db->prepare("
            INSERT INTO wp_recommended_plugins 
            (slug, name, description, category, install_url, is_active, sort_order) 
            VALUES (?, ?, ?, ?, ?, ?, ?)
        ");
        
        $stmt->execute([
            $pluginData['slug'],
            $pluginData['name'],
            $pluginData['description'] ?? '',
            $pluginData['category'] ?? '',
            $pluginData['install_url'] ?? '',
            $pluginData['is_active'] ? 1 : 0,
            $pluginData['sort_order'] ?? 0
        ]);
        
        $pluginId = $this->db->lastInsertId();
        
        error_log("Recommended plugin added: ID={$pluginId}, Name={$pluginData['name']}, Slug={$pluginData['slug']}");
        
        return $pluginId;
    }
    
    /**
     * Update an existing recommended plugin
     */
    public function updateRecommendedPlugin($pluginId, $pluginData) {
        // Validate required fields
        if (empty($pluginData['name']) || empty($pluginData['slug'])) {
            throw new Exception('Plugin name and slug are required');
        }
        
        // Check if plugin exists
        $stmt = $this->db->prepare("SELECT id FROM wp_recommended_plugins WHERE id = ?");
        $stmt->execute([$pluginId]);
        if (!$stmt->fetch()) {
            throw new Exception('Plugin not found');
        }
        
        // Check if slug conflicts with another plugin
        $stmt = $this->db->prepare("SELECT id FROM wp_recommended_plugins WHERE slug = ? AND id != ?");
        $stmt->execute([$pluginData['slug'], $pluginId]);
        if ($stmt->fetch()) {
            throw new Exception('A plugin with this slug already exists');
        }
        
        $stmt = $this->db->prepare("
            UPDATE wp_recommended_plugins 
            SET slug = ?, name = ?, description = ?, category = ?, install_url = ?, is_active = ?, sort_order = ?
            WHERE id = ?
        ");
        
        $stmt->execute([
            $pluginData['slug'],
            $pluginData['name'],
            $pluginData['description'] ?? '',
            $pluginData['category'] ?? '',
            $pluginData['install_url'] ?? '',
            $pluginData['is_active'] ? 1 : 0,
            $pluginData['sort_order'] ?? 0,
            $pluginId
        ]);
        
        error_log("Recommended plugin updated: ID={$pluginId}, Name={$pluginData['name']}, Slug={$pluginData['slug']}");
        
        return true;
    }
    
    /**
     * Delete a recommended plugin
     */
    public function deleteRecommendedPlugin($pluginId) {
        // Check if plugin exists
        $stmt = $this->db->prepare("SELECT name, slug FROM wp_recommended_plugins WHERE id = ?");
        $stmt->execute([$pluginId]);
        $plugin = $stmt->fetch(PDO::FETCH_ASSOC);
        
        if (!$plugin) {
            throw new Exception('Plugin not found');
        }
        
        // Delete the plugin
        $stmt = $this->db->prepare("DELETE FROM wp_recommended_plugins WHERE id = ?");
        $stmt->execute([$pluginId]);
        
        error_log("Recommended plugin deleted: ID={$pluginId}, Name={$plugin['name']}, Slug={$plugin['slug']}");
        
        return true;
    }
    
    /**
     * Get active recommended plugins for installation display
     */
    public function getActiveRecommendedPlugins() {
        $stmt = $this->db->query("
            SELECT id, slug, name, description, category, install_url, sort_order
            FROM wp_recommended_plugins 
            WHERE is_active = 1
            ORDER BY sort_order ASC, name ASC
        ");
        
        return $stmt->fetchAll(PDO::FETCH_ASSOC);
    }
    
    /**
     * Toggle plugin active status
     */
    public function togglePluginStatus($pluginId, $isActive) {
        $stmt = $this->db->prepare("UPDATE wp_recommended_plugins SET is_active = ? WHERE id = ?");
        $stmt->execute([$isActive ? 1 : 0, $pluginId]);
        
        if ($stmt->rowCount() === 0) {
            throw new Exception('Plugin not found');
        }
        
        error_log("Recommended plugin status toggled: ID={$pluginId}, Active=" . ($isActive ? 'true' : 'false'));
        
        return true;
    }
}